@@ -1,7 +1,5 @@
 package AnyEvent::Handle::UDP;
-{
-  $AnyEvent::Handle::UDP::VERSION = '0.043';
-}
+$AnyEvent::Handle::UDP::VERSION = '0.044';
 use strict;
 use warnings FATAL => 'all';
 
@@ -328,7 +326,7 @@ sub _push_writer {
 				my ($msg, $to, $cv) = @{$entry};
 				my $ret = $self->_send($msg, $to, $cv);
 				if (not defined $ret) {
-					unshift @{$self->_buffers}, $entry;
+					unshift @{$self->_buffers}, $entry if $self->_buffers;
 					last;
 				}
 			}
@@ -355,13 +353,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 AnyEvent::Handle::UDP - client/server UDP handles for AnyEvent
 
 =head1 VERSION
 
-version 0.043
+version 0.044
 
 =head1 SYNOPSIS
 
@@ -407,6 +407,10 @@ Sets the socket family. The default is C<0>, which means either IPv4 or IPv6. Th
 
 The underlying filehandle. Note that this doesn't cooperate with the C<connect> and C<bind> parameters.
 
+=head2 reuse_addr
+
+If true will enable quick reuse of the bound address
+
 =head2 timeout
 
 =head2 rtimeout
@@ -486,6 +490,9 @@ Destroy the handle.
 This module is B<not> backwards compatible in any way with the defunct previous module of the same name by Jan Henning Thorsen. 
 
 =for Pod::Coverage BUILD
+has_timeout
+has_rtimeout
+has_wtimeout
 =end
 
 =head1 AUTHOR
